import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DaemonsetConfig extends cdktf.TerraformMetaArguments {
    /**
     * Wait for the rollout of the deployment to complete. Defaults to true.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#wait_for_rollout Daemonset#wait_for_rollout}
     *
     * @stability stable
     */
    readonly waitForRollout?: boolean;
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#metadata Daemonset#metadata}
     *
     * @stability stable
     */
    readonly metadata: DaemonsetMetadata[];
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#spec Daemonset#spec}
     *
     * @stability stable
     */
    readonly spec: DaemonsetSpec[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#timeouts Daemonset#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DaemonsetTimeouts;
}
/**
 * @stability stable
 */
export interface DaemonsetMetadata {
    /**
     * An unstructured key value map stored with the daemonset that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#annotations Daemonset#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#generate_name Daemonset#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the daemonset.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#labels Daemonset#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the daemonset, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the daemonset must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#namespace Daemonset#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#operator Daemonset#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#values Daemonset#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#match_labels Daemonset#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#match_expressions Daemonset#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: DaemonsetSpecSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecStrategyRollingUpdate {
    /**
     * The maximum number of DaemonSet pods that can be unavailable during the update.
     *
     * Value can be an absolute number (ex: 5) or a percentage of total number of DaemonSet pods at the start of the update (ex: 10%). Absolute number is calculated from percentage by rounding up. This cannot be 0. Default value is 1. Example: when this is set to 30%, at most 30% of the total number of nodes that should be running the daemon pod (i.e. status.desiredNumberScheduled) can have their pods stopped for an update at any given time. The update starts by stopping at most 30% of those DaemonSet pods and then brings up new DaemonSet pods in their place. Once the new pods are available, it then proceeds onto other DaemonSet pods, thus ensuring that at least 70% of original number of DaemonSet pods are available at all times during the update.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#max_unavailable Daemonset#max_unavailable}
     *
     * @stability stable
     */
    readonly maxUnavailable?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecStrategy {
    /**
     * Type of deployment. Can be 'RollingUpdate' or 'OnDelete'. Default is RollingUpdate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#type Daemonset#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * rolling_update block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#rolling_update Daemonset#rolling_update}
     *
     * @stability stable
     */
    readonly rollingUpdate?: DaemonsetSpecStrategyRollingUpdate[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateMetadata {
    /**
     * An unstructured key value map stored with the daemon set that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#annotations Daemonset#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#generate_name Daemonset#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the daemon set.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#labels Daemonset#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the daemon set, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#operator Daemonset#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#values Daemonset#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference {
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#match_expressions Daemonset#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: DaemonsetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight is in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#weight Daemonset#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * preference block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#preference Daemonset#preference}
     *
     * @stability stable
     */
    readonly preference: DaemonsetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#operator Daemonset#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#values Daemonset#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm {
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#match_expressions Daemonset#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: DaemonsetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * node_selector_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#node_selector_term Daemonset#node_selector_term}
     *
     * @stability stable
     */
    readonly nodeSelectorTerm?: DaemonsetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityNodeAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#preferred_during_scheduling_ignored_during_execution Daemonset#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: DaemonsetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#required_during_scheduling_ignored_during_execution Daemonset#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: DaemonsetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#operator Daemonset#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#values Daemonset#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#match_labels Daemonset#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#match_expressions Daemonset#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: DaemonsetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#namespaces Daemonset#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#topology_key Daemonset#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#label_selector Daemonset#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: DaemonsetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#weight Daemonset#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#pod_affinity_term Daemonset#pod_affinity_term}
     *
     * @stability stable
     */
    readonly podAffinityTerm: DaemonsetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#operator Daemonset#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#values Daemonset#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#match_labels Daemonset#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#match_expressions Daemonset#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: DaemonsetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#namespaces Daemonset#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#topology_key Daemonset#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#label_selector Daemonset#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: DaemonsetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityPodAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#preferred_during_scheduling_ignored_during_execution Daemonset#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: DaemonsetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#required_during_scheduling_ignored_during_execution Daemonset#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: DaemonsetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#operator Daemonset#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#values Daemonset#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#match_labels Daemonset#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#match_expressions Daemonset#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: DaemonsetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#namespaces Daemonset#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#topology_key Daemonset#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#label_selector Daemonset#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: DaemonsetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#weight Daemonset#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#pod_affinity_term Daemonset#pod_affinity_term}
     *
     * @stability stable
     */
    readonly podAffinityTerm: DaemonsetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#operator Daemonset#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#values Daemonset#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#match_labels Daemonset#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#match_expressions Daemonset#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: DaemonsetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#namespaces Daemonset#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#topology_key Daemonset#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#label_selector Daemonset#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: DaemonsetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinityPodAntiAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#preferred_during_scheduling_ignored_during_execution Daemonset#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: DaemonsetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#required_during_scheduling_ignored_during_execution Daemonset#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: DaemonsetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecAffinity {
    /**
     * node_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#node_affinity Daemonset#node_affinity}
     *
     * @stability stable
     */
    readonly nodeAffinity?: DaemonsetSpecTemplateSpecAffinityNodeAffinity[];
    /**
     * pod_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#pod_affinity Daemonset#pod_affinity}
     *
     * @stability stable
     */
    readonly podAffinity?: DaemonsetSpecTemplateSpecAffinityPodAffinity[];
    /**
     * pod_anti_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#pod_anti_affinity Daemonset#pod_anti_affinity}
     *
     * @stability stable
     */
    readonly podAntiAffinity?: DaemonsetSpecTemplateSpecAffinityPodAntiAffinity[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#optional Daemonset#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#api_version Daemonset#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#field_path Daemonset#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerEnvValueFromResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#container_name Daemonset#container_name}.
     *
     * @stability stable
     */
    readonly containerName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#divisor Daemonset#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#resource Daemonset#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from. Must be a valid secret key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#optional Daemonset#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#config_map_key_ref Daemonset#config_map_key_ref}
     *
     * @stability stable
     */
    readonly configMapKeyRef?: DaemonsetSpecTemplateSpecContainerEnvValueFromConfigMapKeyRef[];
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#field_ref Daemonset#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: DaemonsetSpecTemplateSpecContainerEnvValueFromFieldRef[];
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#resource_field_ref Daemonset#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: DaemonsetSpecTemplateSpecContainerEnvValueFromResourceFieldRef[];
    /**
     * secret_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#secret_key_ref Daemonset#secret_key_ref}
     *
     * @stability stable
     */
    readonly secretKeyRef?: DaemonsetSpecTemplateSpecContainerEnvValueFromSecretKeyRef[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerEnv {
    /**
     * Name of the environment variable. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value Daemonset#value}
     *
     * @stability stable
     */
    readonly value?: string;
    /**
     * value_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value_from Daemonset#value_from}
     *
     * @stability stable
     */
    readonly valueFrom?: DaemonsetSpecTemplateSpecContainerEnvValueFrom[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerEnvFromConfigMapRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#optional Daemonset#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerEnvFromSecretRef {
    /**
     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#optional Daemonset#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#prefix Daemonset#prefix}
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#config_map_ref Daemonset#config_map_ref}
     *
     * @stability stable
     */
    readonly configMapRef?: DaemonsetSpecTemplateSpecContainerEnvFromConfigMapRef[];
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#secret_ref Daemonset#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: DaemonsetSpecTemplateSpecContainerEnvFromSecretRef[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#command Daemonset#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value Daemonset#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host Daemonset#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#scheme Daemonset#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_header Daemonset#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonsetSpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerLifecyclePostStart {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#exec Daemonset#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonsetSpecTemplateSpecContainerLifecyclePostStartExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_get Daemonset#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonsetSpecTemplateSpecContainerLifecyclePostStartHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#tcp_socket Daemonset#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonsetSpecTemplateSpecContainerLifecyclePostStartTcpSocket[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#command Daemonset#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value Daemonset#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host Daemonset#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#scheme Daemonset#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_header Daemonset#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonsetSpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerLifecyclePreStop {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#exec Daemonset#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonsetSpecTemplateSpecContainerLifecyclePreStopExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_get Daemonset#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonsetSpecTemplateSpecContainerLifecyclePreStopHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#tcp_socket Daemonset#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonsetSpecTemplateSpecContainerLifecyclePreStopTcpSocket[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerLifecycle {
    /**
     * post_start block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#post_start Daemonset#post_start}
     *
     * @stability stable
     */
    readonly postStart?: DaemonsetSpecTemplateSpecContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#pre_stop Daemonset#pre_stop}
     *
     * @stability stable
     */
    readonly preStop?: DaemonsetSpecTemplateSpecContainerLifecyclePreStop[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#command Daemonset#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value Daemonset#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host Daemonset#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#scheme Daemonset#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_header Daemonset#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonsetSpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#failure_threshold Daemonset#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#initial_delay_seconds Daemonset#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#period_seconds Daemonset#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#success_threshold Daemonset#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#timeout_seconds Daemonset#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#exec Daemonset#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonsetSpecTemplateSpecContainerLivenessProbeExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_get Daemonset#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonsetSpecTemplateSpecContainerLivenessProbeHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#tcp_socket Daemonset#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonsetSpecTemplateSpecContainerLivenessProbeTcpSocket[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#container_port Daemonset#container_port}
     *
     * @stability stable
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host_ip Daemonset#host_ip}
     *
     * @stability stable
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host_port Daemonset#host_port}
     *
     * @stability stable
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Protocol for port. Must be UDP or TCP. Defaults to "TCP".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#protocol Daemonset#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#command Daemonset#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value Daemonset#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host Daemonset#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#scheme Daemonset#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_header Daemonset#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonsetSpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#failure_threshold Daemonset#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#initial_delay_seconds Daemonset#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#period_seconds Daemonset#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#success_threshold Daemonset#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#timeout_seconds Daemonset#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#exec Daemonset#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonsetSpecTemplateSpecContainerReadinessProbeExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_get Daemonset#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonsetSpecTemplateSpecContainerReadinessProbeHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#tcp_socket Daemonset#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonsetSpecTemplateSpecContainerReadinessProbeTcpSocket[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerResources {
    /**
     * Describes the maximum amount of compute resources allowed. More info: http://kubernetes.io/docs/user-guide/compute-resources/.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#limits Daemonset#limits}
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    };
    /**
     * Requests describes the minimum amount of compute resources required.
     *
     * If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-compute-resources-container/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#requests Daemonset#requests}
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    };
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#add Daemonset#add}
     *
     * @stability stable
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#drop Daemonset#drop}
     *
     * @stability stable
     */
    readonly drop?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#level Daemonset#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#role Daemonset#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#type Daemonset#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#user Daemonset#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#allow_privilege_escalation Daemonset#allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly allowPrivilegeEscalation?: boolean;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#privileged Daemonset#privileged}
     *
     * @stability stable
     */
    readonly privileged?: boolean;
    /**
     * Whether this container has a read-only root filesystem. Default is false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only_root_filesystem Daemonset#read_only_root_filesystem}
     *
     * @stability stable
     */
    readonly readOnlyRootFilesystem?: boolean;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#run_as_group Daemonset#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#run_as_non_root Daemonset#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#run_as_user Daemonset#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * capabilities block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#capabilities Daemonset#capabilities}
     *
     * @stability stable
     */
    readonly capabilities?: DaemonsetSpecTemplateSpecContainerSecurityContextCapabilities[];
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#se_linux_options Daemonset#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: DaemonsetSpecTemplateSpecContainerSecurityContextSeLinuxOptions[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#command Daemonset#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value Daemonset#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host Daemonset#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#scheme Daemonset#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_header Daemonset#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonsetSpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#failure_threshold Daemonset#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#initial_delay_seconds Daemonset#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#period_seconds Daemonset#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#success_threshold Daemonset#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#timeout_seconds Daemonset#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#exec Daemonset#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonsetSpecTemplateSpecContainerStartupProbeExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_get Daemonset#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonsetSpecTemplateSpecContainerStartupProbeHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#tcp_socket Daemonset#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonsetSpecTemplateSpecContainerStartupProbeTcpSocket[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted. Must not contain ':'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#mount_path Daemonset#mount_path}
     *
     * @stability stable
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#mount_propagation Daemonset#mount_propagation}
     *
     * @stability stable
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#sub_path Daemonset#sub_path}
     *
     * @stability stable
     */
    readonly subPath?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#args Daemonset#args}
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#command Daemonset#command}
     *
     * @stability stable
     */
    readonly command?: string[];
    /**
     * Docker image name. More info: http://kubernetes.io/docs/user-guide/images.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#image Daemonset#image}
     *
     * @stability stable
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#image_pull_policy Daemonset#image_pull_policy}
     *
     * @stability stable
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#stdin Daemonset#stdin}
     *
     * @stability stable
     */
    readonly stdin?: boolean;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#stdin_once Daemonset#stdin_once}
     *
     * @stability stable
     */
    readonly stdinOnce?: boolean;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#termination_message_path Daemonset#termination_message_path}
     *
     * @stability stable
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#termination_message_policy Daemonset#termination_message_policy}
     *
     * @stability stable
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#tty Daemonset#tty}
     *
     * @stability stable
     */
    readonly tty?: boolean;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#working_dir Daemonset#working_dir}
     *
     * @stability stable
     */
    readonly workingDir?: string;
    /**
     * env block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#env Daemonset#env}
     *
     * @stability stable
     */
    readonly env?: DaemonsetSpecTemplateSpecContainerEnv[];
    /**
     * env_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#env_from Daemonset#env_from}
     *
     * @stability stable
     */
    readonly envFrom?: DaemonsetSpecTemplateSpecContainerEnvFrom[];
    /**
     * lifecycle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#lifecycle Daemonset#lifecycle}
     *
     * @stability stable
     */
    readonly lifecycle?: DaemonsetSpecTemplateSpecContainerLifecycle[];
    /**
     * liveness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#liveness_probe Daemonset#liveness_probe}
     *
     * @stability stable
     */
    readonly livenessProbe?: DaemonsetSpecTemplateSpecContainerLivenessProbe[];
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port?: DaemonsetSpecTemplateSpecContainerPort[];
    /**
     * readiness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#readiness_probe Daemonset#readiness_probe}
     *
     * @stability stable
     */
    readonly readinessProbe?: DaemonsetSpecTemplateSpecContainerReadinessProbe[];
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#resources Daemonset#resources}
     *
     * @stability stable
     */
    readonly resources?: DaemonsetSpecTemplateSpecContainerResources[];
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#security_context Daemonset#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: DaemonsetSpecTemplateSpecContainerSecurityContext[];
    /**
     * startup_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#startup_probe Daemonset#startup_probe}
     *
     * @stability stable
     */
    readonly startupProbe?: DaemonsetSpecTemplateSpecContainerStartupProbe[];
    /**
     * volume_mount block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#volume_mount Daemonset#volume_mount}
     *
     * @stability stable
     */
    readonly volumeMount?: DaemonsetSpecTemplateSpecContainerVolumeMount[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecDnsConfigOption {
    /**
     * Name of the option.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Value of the option. Optional: Defaults to empty.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value Daemonset#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecDnsConfig {
    /**
     * A list of DNS name server IP addresses.
     *
     * This will be appended to the base nameservers generated from DNSPolicy. Duplicated nameservers will be removed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#nameservers Daemonset#nameservers}
     *
     * @stability stable
     */
    readonly nameservers?: string[];
    /**
     * A list of DNS search domains for host-name lookup.
     *
     * This will be appended to the base search paths generated from DNSPolicy. Duplicated search paths will be removed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#searches Daemonset#searches}
     *
     * @stability stable
     */
    readonly searches?: string[];
    /**
     * option block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#option Daemonset#option}
     *
     * @stability stable
     */
    readonly option?: DaemonsetSpecTemplateSpecDnsConfigOption[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecHostAliases {
    /**
     * Hostnames for the IP address.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#hostnames Daemonset#hostnames}
     *
     * @stability stable
     */
    readonly hostnames: string[];
    /**
     * IP address of the host file entry.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#ip Daemonset#ip}
     *
     * @stability stable
     */
    readonly ip: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecImagePullSecrets {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#optional Daemonset#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#api_version Daemonset#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#field_path Daemonset#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerEnvValueFromResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#container_name Daemonset#container_name}.
     *
     * @stability stable
     */
    readonly containerName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#divisor Daemonset#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#resource Daemonset#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from. Must be a valid secret key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#optional Daemonset#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#config_map_key_ref Daemonset#config_map_key_ref}
     *
     * @stability stable
     */
    readonly configMapKeyRef?: DaemonsetSpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef[];
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#field_ref Daemonset#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: DaemonsetSpecTemplateSpecInitContainerEnvValueFromFieldRef[];
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#resource_field_ref Daemonset#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: DaemonsetSpecTemplateSpecInitContainerEnvValueFromResourceFieldRef[];
    /**
     * secret_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#secret_key_ref Daemonset#secret_key_ref}
     *
     * @stability stable
     */
    readonly secretKeyRef?: DaemonsetSpecTemplateSpecInitContainerEnvValueFromSecretKeyRef[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerEnv {
    /**
     * Name of the environment variable. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value Daemonset#value}
     *
     * @stability stable
     */
    readonly value?: string;
    /**
     * value_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value_from Daemonset#value_from}
     *
     * @stability stable
     */
    readonly valueFrom?: DaemonsetSpecTemplateSpecInitContainerEnvValueFrom[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerEnvFromConfigMapRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#optional Daemonset#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerEnvFromSecretRef {
    /**
     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#optional Daemonset#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#prefix Daemonset#prefix}
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#config_map_ref Daemonset#config_map_ref}
     *
     * @stability stable
     */
    readonly configMapRef?: DaemonsetSpecTemplateSpecInitContainerEnvFromConfigMapRef[];
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#secret_ref Daemonset#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: DaemonsetSpecTemplateSpecInitContainerEnvFromSecretRef[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#command Daemonset#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value Daemonset#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host Daemonset#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#scheme Daemonset#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_header Daemonset#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonsetSpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerLifecyclePostStart {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#exec Daemonset#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonsetSpecTemplateSpecInitContainerLifecyclePostStartExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_get Daemonset#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonsetSpecTemplateSpecInitContainerLifecyclePostStartHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#tcp_socket Daemonset#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonsetSpecTemplateSpecInitContainerLifecyclePostStartTcpSocket[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#command Daemonset#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value Daemonset#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host Daemonset#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#scheme Daemonset#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_header Daemonset#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonsetSpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerLifecyclePreStop {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#exec Daemonset#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonsetSpecTemplateSpecInitContainerLifecyclePreStopExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_get Daemonset#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonsetSpecTemplateSpecInitContainerLifecyclePreStopHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#tcp_socket Daemonset#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonsetSpecTemplateSpecInitContainerLifecyclePreStopTcpSocket[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerLifecycle {
    /**
     * post_start block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#post_start Daemonset#post_start}
     *
     * @stability stable
     */
    readonly postStart?: DaemonsetSpecTemplateSpecInitContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#pre_stop Daemonset#pre_stop}
     *
     * @stability stable
     */
    readonly preStop?: DaemonsetSpecTemplateSpecInitContainerLifecyclePreStop[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#command Daemonset#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value Daemonset#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host Daemonset#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#scheme Daemonset#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_header Daemonset#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonsetSpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#failure_threshold Daemonset#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#initial_delay_seconds Daemonset#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#period_seconds Daemonset#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#success_threshold Daemonset#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#timeout_seconds Daemonset#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#exec Daemonset#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonsetSpecTemplateSpecInitContainerLivenessProbeExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_get Daemonset#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonsetSpecTemplateSpecInitContainerLivenessProbeHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#tcp_socket Daemonset#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonsetSpecTemplateSpecInitContainerLivenessProbeTcpSocket[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#container_port Daemonset#container_port}
     *
     * @stability stable
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host_ip Daemonset#host_ip}
     *
     * @stability stable
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host_port Daemonset#host_port}
     *
     * @stability stable
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Protocol for port. Must be UDP or TCP. Defaults to "TCP".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#protocol Daemonset#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#command Daemonset#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value Daemonset#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host Daemonset#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#scheme Daemonset#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_header Daemonset#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonsetSpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#failure_threshold Daemonset#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#initial_delay_seconds Daemonset#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#period_seconds Daemonset#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#success_threshold Daemonset#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#timeout_seconds Daemonset#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#exec Daemonset#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonsetSpecTemplateSpecInitContainerReadinessProbeExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_get Daemonset#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonsetSpecTemplateSpecInitContainerReadinessProbeHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#tcp_socket Daemonset#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonsetSpecTemplateSpecInitContainerReadinessProbeTcpSocket[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerResources {
    /**
     * Describes the maximum amount of compute resources allowed. More info: http://kubernetes.io/docs/user-guide/compute-resources/.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#limits Daemonset#limits}
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    };
    /**
     * Requests describes the minimum amount of compute resources required.
     *
     * If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-compute-resources-container/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#requests Daemonset#requests}
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    };
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#add Daemonset#add}
     *
     * @stability stable
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#drop Daemonset#drop}
     *
     * @stability stable
     */
    readonly drop?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#level Daemonset#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#role Daemonset#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#type Daemonset#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#user Daemonset#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#allow_privilege_escalation Daemonset#allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly allowPrivilegeEscalation?: boolean;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#privileged Daemonset#privileged}
     *
     * @stability stable
     */
    readonly privileged?: boolean;
    /**
     * Whether this container has a read-only root filesystem. Default is false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only_root_filesystem Daemonset#read_only_root_filesystem}
     *
     * @stability stable
     */
    readonly readOnlyRootFilesystem?: boolean;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#run_as_group Daemonset#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#run_as_non_root Daemonset#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#run_as_user Daemonset#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * capabilities block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#capabilities Daemonset#capabilities}
     *
     * @stability stable
     */
    readonly capabilities?: DaemonsetSpecTemplateSpecInitContainerSecurityContextCapabilities[];
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#se_linux_options Daemonset#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: DaemonsetSpecTemplateSpecInitContainerSecurityContextSeLinuxOptions[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#command Daemonset#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value Daemonset#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host Daemonset#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#scheme Daemonset#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_header Daemonset#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonsetSpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#failure_threshold Daemonset#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#initial_delay_seconds Daemonset#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#period_seconds Daemonset#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#success_threshold Daemonset#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#timeout_seconds Daemonset#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#exec Daemonset#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonsetSpecTemplateSpecInitContainerStartupProbeExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#http_get Daemonset#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonsetSpecTemplateSpecInitContainerStartupProbeHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#tcp_socket Daemonset#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonsetSpecTemplateSpecInitContainerStartupProbeTcpSocket[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted. Must not contain ':'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#mount_path Daemonset#mount_path}
     *
     * @stability stable
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#mount_propagation Daemonset#mount_propagation}
     *
     * @stability stable
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#sub_path Daemonset#sub_path}
     *
     * @stability stable
     */
    readonly subPath?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecInitContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#args Daemonset#args}
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#command Daemonset#command}
     *
     * @stability stable
     */
    readonly command?: string[];
    /**
     * Docker image name. More info: http://kubernetes.io/docs/user-guide/images.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#image Daemonset#image}
     *
     * @stability stable
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#image_pull_policy Daemonset#image_pull_policy}
     *
     * @stability stable
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#stdin Daemonset#stdin}
     *
     * @stability stable
     */
    readonly stdin?: boolean;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#stdin_once Daemonset#stdin_once}
     *
     * @stability stable
     */
    readonly stdinOnce?: boolean;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#termination_message_path Daemonset#termination_message_path}
     *
     * @stability stable
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#termination_message_policy Daemonset#termination_message_policy}
     *
     * @stability stable
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#tty Daemonset#tty}
     *
     * @stability stable
     */
    readonly tty?: boolean;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#working_dir Daemonset#working_dir}
     *
     * @stability stable
     */
    readonly workingDir?: string;
    /**
     * env block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#env Daemonset#env}
     *
     * @stability stable
     */
    readonly env?: DaemonsetSpecTemplateSpecInitContainerEnv[];
    /**
     * env_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#env_from Daemonset#env_from}
     *
     * @stability stable
     */
    readonly envFrom?: DaemonsetSpecTemplateSpecInitContainerEnvFrom[];
    /**
     * lifecycle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#lifecycle Daemonset#lifecycle}
     *
     * @stability stable
     */
    readonly lifecycle?: DaemonsetSpecTemplateSpecInitContainerLifecycle[];
    /**
     * liveness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#liveness_probe Daemonset#liveness_probe}
     *
     * @stability stable
     */
    readonly livenessProbe?: DaemonsetSpecTemplateSpecInitContainerLivenessProbe[];
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#port Daemonset#port}
     *
     * @stability stable
     */
    readonly port?: DaemonsetSpecTemplateSpecInitContainerPort[];
    /**
     * readiness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#readiness_probe Daemonset#readiness_probe}
     *
     * @stability stable
     */
    readonly readinessProbe?: DaemonsetSpecTemplateSpecInitContainerReadinessProbe[];
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#resources Daemonset#resources}
     *
     * @stability stable
     */
    readonly resources?: DaemonsetSpecTemplateSpecInitContainerResources[];
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#security_context Daemonset#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: DaemonsetSpecTemplateSpecInitContainerSecurityContext[];
    /**
     * startup_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#startup_probe Daemonset#startup_probe}
     *
     * @stability stable
     */
    readonly startupProbe?: DaemonsetSpecTemplateSpecInitContainerStartupProbe[];
    /**
     * volume_mount block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#volume_mount Daemonset#volume_mount}
     *
     * @stability stable
     */
    readonly volumeMount?: DaemonsetSpecTemplateSpecInitContainerVolumeMount[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecReadinessGate {
    /**
     * refers to a condition in the pod's condition list with matching type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#condition_type Daemonset#condition_type}
     *
     * @stability stable
     */
    readonly conditionType: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#level Daemonset#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#role Daemonset#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#type Daemonset#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#user Daemonset#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecSecurityContextSysctl {
    /**
     * Name of a property to set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Value of a property to set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value Daemonset#value}
     *
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecSecurityContext {
    /**
     * A special supplemental group that applies to all containers in a pod.
     *
     * Some volume types allow the Kubelet to change the ownership of that volume to be owned by the pod: 1. The owning GID will be the FSGroup 2. The setgid bit is set (new files created in the volume will be owned by FSGroup) 3. The permission bits are OR'd with rw-rw---- If unset, the Kubelet will not modify the ownership and permissions of any volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#fs_group Daemonset#fs_group}
     *
     * @stability stable
     */
    readonly fsGroup?: string;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#run_as_group Daemonset#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#run_as_non_root Daemonset#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#run_as_user Daemonset#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * A list of groups applied to the first process run in each container, in addition to the container's primary GID.
     *
     * If unspecified, no groups will be added to any container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#supplemental_groups Daemonset#supplemental_groups}
     *
     * @stability stable
     */
    readonly supplementalGroups?: number[];
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#se_linux_options Daemonset#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: DaemonsetSpecTemplateSpecSecurityContextSeLinuxOptions[];
    /**
     * sysctl block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#sysctl Daemonset#sysctl}
     *
     * @stability stable
     */
    readonly sysctl?: DaemonsetSpecTemplateSpecSecurityContextSysctl[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecToleration {
    /**
     * Effect indicates the taint effect to match.
     *
     * Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#effect Daemonset#effect}
     *
     * @stability stable
     */
    readonly effect?: string;
    /**
     * Key is the taint key that the toleration applies to.
     *
     * Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to the value.
     *
     * Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#operator Daemonset#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint.
     *
     * By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#toleration_seconds Daemonset#toleration_seconds}
     *
     * @stability stable
     */
    readonly tolerationSeconds?: string;
    /**
     * Value is the taint value the toleration matches to.
     *
     * If the operator is Exists, the value should be empty, otherwise just a regular string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#value Daemonset#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#operator Daemonset#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#values Daemonset#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecTopologySpreadConstraintLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#match_labels Daemonset#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#match_expressions Daemonset#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: DaemonsetSpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecTopologySpreadConstraint {
    /**
     * describes the degree to which pods may be unevenly distributed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#max_skew Daemonset#max_skew}
     *
     * @stability stable
     */
    readonly maxSkew?: number;
    /**
     * the key of node labels.
     *
     * Nodes that have a label with this key and identical values are considered to be in the same topology.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#topology_key Daemonset#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * indicates how to deal with a pod if it doesn't satisfy the spread constraint.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#when_unsatisfiable Daemonset#when_unsatisfiable}
     *
     * @stability stable
     */
    readonly whenUnsatisfiable?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#label_selector Daemonset#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: DaemonsetSpecTemplateSpecTopologySpreadConstraintLabelSelector[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeAwsElasticBlockStore {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#fs_type Daemonset#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#partition Daemonset#partition}
     *
     * @stability stable
     */
    readonly partition?: number;
    /**
     * Whether to set the read-only property in VolumeMounts to "true". If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Unique ID of the persistent disk resource in AWS (Amazon EBS volume). More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#volume_id Daemonset#volume_id}
     *
     * @stability stable
     */
    readonly volumeId: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeAzureDisk {
    /**
     * Host Caching mode: None, Read Only, Read Write.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#caching_mode Daemonset#caching_mode}
     *
     * @stability stable
     */
    readonly cachingMode: string;
    /**
     * The URI the data disk in the blob storage.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#data_disk_uri Daemonset#data_disk_uri}
     *
     * @stability stable
     */
    readonly dataDiskUri: string;
    /**
     * The Name of the data disk in the blob storage.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#disk_name Daemonset#disk_name}
     *
     * @stability stable
     */
    readonly diskName: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#fs_type Daemonset#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The type for the data disk. Expected values: Shared, Dedicated, Managed. Defaults to Shared.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#kind Daemonset#kind}
     *
     * @stability stable
     */
    readonly kind?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeAzureFile {
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * The name of secret that contains Azure Storage Account Name and Key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#secret_name Daemonset#secret_name}
     *
     * @stability stable
     */
    readonly secretName: string;
    /**
     * The namespace of the secret that contains Azure Storage Account Name and Key.
     *
     * For Kubernetes up to 1.18.x the default is the same as the Pod. For Kubernetes 1.19.x and later the default is "default" namespace.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#secret_namespace Daemonset#secret_namespace}
     *
     * @stability stable
     */
    readonly secretNamespace?: string;
    /**
     * Share Name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#share_name Daemonset#share_name}
     *
     * @stability stable
     */
    readonly shareName: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeCephFsSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#namespace Daemonset#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeCephFs {
    /**
     * Monitors is a collection of Ceph monitors More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#monitors Daemonset#monitors}
     *
     * @stability stable
     */
    readonly monitors: string[];
    /**
     * Used as the mounted root, rather than the full Ceph tree, default is /.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to `false` (read/write). More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * The path to key ring for User, default is /etc/ceph/user.secret More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#secret_file Daemonset#secret_file}
     *
     * @stability stable
     */
    readonly secretFile?: string;
    /**
     * User is the rados user name, default is admin. More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#user Daemonset#user}
     *
     * @stability stable
     */
    readonly user?: string;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#secret_ref Daemonset#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: DaemonsetSpecTemplateSpecVolumeCephFsSecretRef[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeCinder {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#fs_type Daemonset#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write). More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Volume ID used to identify the volume in Cinder. More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#volume_id Daemonset#volume_id}
     *
     * @stability stable
     */
    readonly volumeId: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeConfigMapItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#mode Daemonset#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeConfigMap {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#default_mode Daemonset#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or its keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#optional Daemonset#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#items Daemonset#items}
     *
     * @stability stable
     */
    readonly items?: DaemonsetSpecTemplateSpecVolumeConfigMapItems[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeCsiControllerExpandSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#namespace Daemonset#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeCsiControllerPublishSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#namespace Daemonset#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeCsiNodePublishSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#namespace Daemonset#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeCsiNodeStageSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#namespace Daemonset#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeCsi {
    /**
     * the name of the volume driver to use. More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#driver Daemonset#driver}
     *
     * @stability stable
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#fs_type Daemonset#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Whether to set the read-only property in VolumeMounts to "true". If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Attributes of the volume to publish.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#volume_attributes Daemonset#volume_attributes}
     *
     * @stability stable
     */
    readonly volumeAttributes?: {
        [key: string]: string;
    };
    /**
     * A string value that uniquely identifies the volume. More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#volume_handle Daemonset#volume_handle}
     *
     * @stability stable
     */
    readonly volumeHandle: string;
    /**
     * controller_expand_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#controller_expand_secret_ref Daemonset#controller_expand_secret_ref}
     *
     * @stability stable
     */
    readonly controllerExpandSecretRef?: DaemonsetSpecTemplateSpecVolumeCsiControllerExpandSecretRef[];
    /**
     * controller_publish_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#controller_publish_secret_ref Daemonset#controller_publish_secret_ref}
     *
     * @stability stable
     */
    readonly controllerPublishSecretRef?: DaemonsetSpecTemplateSpecVolumeCsiControllerPublishSecretRef[];
    /**
     * node_publish_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#node_publish_secret_ref Daemonset#node_publish_secret_ref}
     *
     * @stability stable
     */
    readonly nodePublishSecretRef?: DaemonsetSpecTemplateSpecVolumeCsiNodePublishSecretRef[];
    /**
     * node_stage_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#node_stage_secret_ref Daemonset#node_stage_secret_ref}
     *
     * @stability stable
     */
    readonly nodeStageSecretRef?: DaemonsetSpecTemplateSpecVolumeCsiNodeStageSecretRef[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#api_version Daemonset#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#field_path Daemonset#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#container_name Daemonset#container_name}.
     *
     * @stability stable
     */
    readonly containerName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#divisor Daemonset#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#resource Daemonset#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeDownwardApiItems {
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#mode Daemonset#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#field_ref Daemonset#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef: DaemonsetSpecTemplateSpecVolumeDownwardApiItemsFieldRef[];
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#resource_field_ref Daemonset#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: DaemonsetSpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeDownwardApi {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#default_mode Daemonset#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#items Daemonset#items}
     *
     * @stability stable
     */
    readonly items?: DaemonsetSpecTemplateSpecVolumeDownwardApiItems[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeEmptyDir {
    /**
     * What type of storage medium should back this directory.
     *
     * The default is "" which means to use the node's default medium. Must be an empty string (default) or Memory. More info: http://kubernetes.io/docs/user-guide/volumes#emptydir
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#medium Daemonset#medium}
     *
     * @stability stable
     */
    readonly medium?: string;
    /**
     * Total amount of local storage required for this EmptyDir volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#size_limit Daemonset#size_limit}
     *
     * @stability stable
     */
    readonly sizeLimit?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeFc {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#fs_type Daemonset#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * FC target lun number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#lun Daemonset#lun}
     *
     * @stability stable
     */
    readonly lun: number;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * FC target worldwide names (WWNs).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#target_ww_ns Daemonset#target_ww_ns}
     *
     * @stability stable
     */
    readonly targetWwNs: string[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeFlexVolumeSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#namespace Daemonset#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeFlexVolume {
    /**
     * Driver is the name of the driver to use for this volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#driver Daemonset#driver}
     *
     * @stability stable
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#fs_type Daemonset#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Extra command options if any.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#options Daemonset#options}
     *
     * @stability stable
     */
    readonly options?: {
        [key: string]: string;
    };
    /**
     * Whether to force the ReadOnly setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#secret_ref Daemonset#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: DaemonsetSpecTemplateSpecVolumeFlexVolumeSecretRef[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeFlocker {
    /**
     * Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#dataset_name Daemonset#dataset_name}
     *
     * @stability stable
     */
    readonly datasetName?: string;
    /**
     * UUID of the dataset. This is unique identifier of a Flocker dataset.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#dataset_uuid Daemonset#dataset_uuid}
     *
     * @stability stable
     */
    readonly datasetUuid?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeGcePersistentDisk {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#fs_type Daemonset#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#partition Daemonset#partition}
     *
     * @stability stable
     */
    readonly partition?: number;
    /**
     * Unique name of the PD resource in GCE. Used to identify the disk in GCE. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#pd_name Daemonset#pd_name}
     *
     * @stability stable
     */
    readonly pdName: string;
    /**
     * Whether to force the ReadOnly setting in VolumeMounts. Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeGitRepo {
    /**
     * Target directory name.
     *
     * Must not contain or start with '..'. If '.' is supplied, the volume directory will be the git repository. Otherwise, if specified, the volume will contain the git repository in the subdirectory with the given name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#directory Daemonset#directory}
     *
     * @stability stable
     */
    readonly directory?: string;
    /**
     * Repository URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#repository Daemonset#repository}
     *
     * @stability stable
     */
    readonly repository?: string;
    /**
     * Commit hash for the specified revision.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#revision Daemonset#revision}
     *
     * @stability stable
     */
    readonly revision?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeGlusterfs {
    /**
     * The endpoint name that details Glusterfs topology. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#endpoints_name Daemonset#endpoints_name}
     *
     * @stability stable
     */
    readonly endpointsName: string;
    /**
     * The Glusterfs volume path. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Whether to force the Glusterfs volume to be mounted with read-only permissions. Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeHostPath {
    /**
     * Path of the directory on the host. More info: http://kubernetes.io/docs/user-guide/volumes#hostpath.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Type for HostPath volume. Allowed values are "" (default), DirectoryOrCreate, Directory, FileOrCreate, File, Socket, CharDevice and BlockDevice.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#type Daemonset#type}
     *
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeIscsi {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#iscsi
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#fs_type Daemonset#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Target iSCSI Qualified Name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#iqn Daemonset#iqn}
     *
     * @stability stable
     */
    readonly iqn: string;
    /**
     * iSCSI interface name that uses an iSCSI transport. Defaults to 'default' (tcp).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#iscsi_interface Daemonset#iscsi_interface}
     *
     * @stability stable
     */
    readonly iscsiInterface?: string;
    /**
     * iSCSI target lun number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#lun Daemonset#lun}
     *
     * @stability stable
     */
    readonly lun?: number;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * iSCSI target portal.
     *
     * The portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#target_portal Daemonset#target_portal}
     *
     * @stability stable
     */
    readonly targetPortal: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeLocal {
    /**
     * Path of the directory on the host. More info: http://kubernetes.io/docs/user-guide/volumes#local.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeNfs {
    /**
     * Path that is exported by the NFS server. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Whether to force the NFS export to be mounted with read-only permissions. Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Server is the hostname or IP address of the NFS server. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#server Daemonset#server}
     *
     * @stability stable
     */
    readonly server: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumePersistentVolumeClaim {
    /**
     * ClaimName is the name of a PersistentVolumeClaim in the same.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#claim_name Daemonset#claim_name}
     *
     * @stability stable
     */
    readonly claimName?: string;
    /**
     * Will force the ReadOnly setting in VolumeMounts.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumePhotonPersistentDisk {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#fs_type Daemonset#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * ID that identifies Photon Controller persistent disk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#pd_id Daemonset#pd_id}
     *
     * @stability stable
     */
    readonly pdId: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeProjectedSourcesConfigMapItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#mode Daemonset#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeProjectedSourcesConfigMap {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or it's keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#optional Daemonset#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#items Daemonset#items}
     *
     * @stability stable
     */
    readonly items?: DaemonsetSpecTemplateSpecVolumeProjectedSourcesConfigMapItems[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to 'v1'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#api_version Daemonset#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#field_path Daemonset#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#container_name Daemonset#container_name}.
     *
     * @stability stable
     */
    readonly containerName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#divisor Daemonset#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#resource Daemonset#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItems {
    /**
     * Mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#mode Daemonset#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#field_ref Daemonset#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: DaemonsetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef[];
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#resource_field_ref Daemonset#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: DaemonsetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeProjectedSourcesDownwardApi {
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#items Daemonset#items}
     *
     * @stability stable
     */
    readonly items?: DaemonsetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeProjectedSourcesSecretItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#mode Daemonset#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeProjectedSourcesSecret {
    /**
     * Name of the secret in the pod's namespace to use. More info: http://kubernetes.io/docs/user-guide/volumes#secrets.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the Secret or it's keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#optional Daemonset#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#items Daemonset#items}
     *
     * @stability stable
     */
    readonly items?: DaemonsetSpecTemplateSpecVolumeProjectedSourcesSecretItems[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeProjectedSourcesServiceAccountToken {
    /**
     * Audience is the intended audience of the token.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#audience Daemonset#audience}
     *
     * @stability stable
     */
    readonly audience?: string;
    /**
     * ExpirationSeconds is the expected duration of validity of the service account token.
     *
     * It defaults to 1 hour and must be at least 10 minutes (600 seconds).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#expiration_seconds Daemonset#expiration_seconds}
     *
     * @stability stable
     */
    readonly expirationSeconds?: number;
    /**
     * Path specifies a relative path to the mount point of the projected volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeProjectedSources {
    /**
     * config_map block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#config_map Daemonset#config_map}
     *
     * @stability stable
     */
    readonly configMap?: DaemonsetSpecTemplateSpecVolumeProjectedSourcesConfigMap[];
    /**
     * downward_api block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#downward_api Daemonset#downward_api}
     *
     * @stability stable
     */
    readonly downwardApi?: DaemonsetSpecTemplateSpecVolumeProjectedSourcesDownwardApi[];
    /**
     * secret block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#secret Daemonset#secret}
     *
     * @stability stable
     */
    readonly secret?: DaemonsetSpecTemplateSpecVolumeProjectedSourcesSecret[];
    /**
     * service_account_token block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#service_account_token Daemonset#service_account_token}
     *
     * @stability stable
     */
    readonly serviceAccountToken?: DaemonsetSpecTemplateSpecVolumeProjectedSourcesServiceAccountToken[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeProjected {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#default_mode Daemonset#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * sources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#sources Daemonset#sources}
     *
     * @stability stable
     */
    readonly sources: DaemonsetSpecTemplateSpecVolumeProjectedSources[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeQuobyte {
    /**
     * Group to map volume access to Default is no group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#group Daemonset#group}
     *
     * @stability stable
     */
    readonly group?: string;
    /**
     * Whether to force the Quobyte volume to be mounted with read-only permissions. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#registry Daemonset#registry}
     *
     * @stability stable
     */
    readonly registry: string;
    /**
     * User to map volume access to Defaults to serivceaccount user.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#user Daemonset#user}
     *
     * @stability stable
     */
    readonly user?: string;
    /**
     * Volume is a string that references an already created Quobyte volume by name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#volume Daemonset#volume}
     *
     * @stability stable
     */
    readonly volume: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeRbdSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#namespace Daemonset#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeRbd {
    /**
     * A collection of Ceph monitors. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#ceph_monitors Daemonset#ceph_monitors}
     *
     * @stability stable
     */
    readonly cephMonitors: string[];
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#rbd
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#fs_type Daemonset#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Keyring is the path to key ring for RBDUser. Default is /etc/ceph/keyring. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#keyring Daemonset#keyring}
     *
     * @stability stable
     */
    readonly keyring?: string;
    /**
     * The rados user name. Default is admin. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#rados_user Daemonset#rados_user}
     *
     * @stability stable
     */
    readonly radosUser?: string;
    /**
     * The rados image name. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#rbd_image Daemonset#rbd_image}
     *
     * @stability stable
     */
    readonly rbdImage: string;
    /**
     * The rados pool name. Default is rbd. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#rbd_pool Daemonset#rbd_pool}
     *
     * @stability stable
     */
    readonly rbdPool?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#read_only Daemonset#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#secret_ref Daemonset#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: DaemonsetSpecTemplateSpecVolumeRbdSecretRef[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeSecretItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#key Daemonset#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#mode Daemonset#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#path Daemonset#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeSecret {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#default_mode Daemonset#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * Optional: Specify whether the Secret or its keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#optional Daemonset#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
    /**
     * Name of the secret in the pod's namespace to use. More info: http://kubernetes.io/docs/user-guide/volumes#secrets.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#secret_name Daemonset#secret_name}
     *
     * @stability stable
     */
    readonly secretName?: string;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#items Daemonset#items}
     *
     * @stability stable
     */
    readonly items?: DaemonsetSpecTemplateSpecVolumeSecretItems[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolumeVsphereVolume {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#fs_type Daemonset#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Path that identifies vSphere volume vmdk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#volume_path Daemonset#volume_path}
     *
     * @stability stable
     */
    readonly volumePath: string;
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpecVolume {
    /**
     * Volume's name. Must be a DNS_LABEL and unique within the pod. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#name Daemonset#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * aws_elastic_block_store block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#aws_elastic_block_store Daemonset#aws_elastic_block_store}
     *
     * @stability stable
     */
    readonly awsElasticBlockStore?: DaemonsetSpecTemplateSpecVolumeAwsElasticBlockStore[];
    /**
     * azure_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#azure_disk Daemonset#azure_disk}
     *
     * @stability stable
     */
    readonly azureDisk?: DaemonsetSpecTemplateSpecVolumeAzureDisk[];
    /**
     * azure_file block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#azure_file Daemonset#azure_file}
     *
     * @stability stable
     */
    readonly azureFile?: DaemonsetSpecTemplateSpecVolumeAzureFile[];
    /**
     * ceph_fs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#ceph_fs Daemonset#ceph_fs}
     *
     * @stability stable
     */
    readonly cephFs?: DaemonsetSpecTemplateSpecVolumeCephFs[];
    /**
     * cinder block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#cinder Daemonset#cinder}
     *
     * @stability stable
     */
    readonly cinder?: DaemonsetSpecTemplateSpecVolumeCinder[];
    /**
     * config_map block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#config_map Daemonset#config_map}
     *
     * @stability stable
     */
    readonly configMap?: DaemonsetSpecTemplateSpecVolumeConfigMap[];
    /**
     * csi block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#csi Daemonset#csi}
     *
     * @stability stable
     */
    readonly csi?: DaemonsetSpecTemplateSpecVolumeCsi[];
    /**
     * downward_api block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#downward_api Daemonset#downward_api}
     *
     * @stability stable
     */
    readonly downwardApi?: DaemonsetSpecTemplateSpecVolumeDownwardApi[];
    /**
     * empty_dir block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#empty_dir Daemonset#empty_dir}
     *
     * @stability stable
     */
    readonly emptyDir?: DaemonsetSpecTemplateSpecVolumeEmptyDir[];
    /**
     * fc block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#fc Daemonset#fc}
     *
     * @stability stable
     */
    readonly fc?: DaemonsetSpecTemplateSpecVolumeFc[];
    /**
     * flex_volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#flex_volume Daemonset#flex_volume}
     *
     * @stability stable
     */
    readonly flexVolume?: DaemonsetSpecTemplateSpecVolumeFlexVolume[];
    /**
     * flocker block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#flocker Daemonset#flocker}
     *
     * @stability stable
     */
    readonly flocker?: DaemonsetSpecTemplateSpecVolumeFlocker[];
    /**
     * gce_persistent_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#gce_persistent_disk Daemonset#gce_persistent_disk}
     *
     * @stability stable
     */
    readonly gcePersistentDisk?: DaemonsetSpecTemplateSpecVolumeGcePersistentDisk[];
    /**
     * git_repo block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#git_repo Daemonset#git_repo}
     *
     * @stability stable
     */
    readonly gitRepo?: DaemonsetSpecTemplateSpecVolumeGitRepo[];
    /**
     * glusterfs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#glusterfs Daemonset#glusterfs}
     *
     * @stability stable
     */
    readonly glusterfs?: DaemonsetSpecTemplateSpecVolumeGlusterfs[];
    /**
     * host_path block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host_path Daemonset#host_path}
     *
     * @stability stable
     */
    readonly hostPath?: DaemonsetSpecTemplateSpecVolumeHostPath[];
    /**
     * iscsi block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#iscsi Daemonset#iscsi}
     *
     * @stability stable
     */
    readonly iscsi?: DaemonsetSpecTemplateSpecVolumeIscsi[];
    /**
     * local block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#local Daemonset#local}
     *
     * @stability stable
     */
    readonly local?: DaemonsetSpecTemplateSpecVolumeLocal[];
    /**
     * nfs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#nfs Daemonset#nfs}
     *
     * @stability stable
     */
    readonly nfs?: DaemonsetSpecTemplateSpecVolumeNfs[];
    /**
     * persistent_volume_claim block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#persistent_volume_claim Daemonset#persistent_volume_claim}
     *
     * @stability stable
     */
    readonly persistentVolumeClaim?: DaemonsetSpecTemplateSpecVolumePersistentVolumeClaim[];
    /**
     * photon_persistent_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#photon_persistent_disk Daemonset#photon_persistent_disk}
     *
     * @stability stable
     */
    readonly photonPersistentDisk?: DaemonsetSpecTemplateSpecVolumePhotonPersistentDisk[];
    /**
     * projected block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#projected Daemonset#projected}
     *
     * @stability stable
     */
    readonly projected?: DaemonsetSpecTemplateSpecVolumeProjected[];
    /**
     * quobyte block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#quobyte Daemonset#quobyte}
     *
     * @stability stable
     */
    readonly quobyte?: DaemonsetSpecTemplateSpecVolumeQuobyte[];
    /**
     * rbd block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#rbd Daemonset#rbd}
     *
     * @stability stable
     */
    readonly rbd?: DaemonsetSpecTemplateSpecVolumeRbd[];
    /**
     * secret block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#secret Daemonset#secret}
     *
     * @stability stable
     */
    readonly secret?: DaemonsetSpecTemplateSpecVolumeSecret[];
    /**
     * vsphere_volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#vsphere_volume Daemonset#vsphere_volume}
     *
     * @stability stable
     */
    readonly vsphereVolume?: DaemonsetSpecTemplateSpecVolumeVsphereVolume[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplateSpec {
    /**
     * Optional duration in seconds the pod may be active on the node relative to StartTime before the system will actively try to mark it failed and kill associated containers.
     *
     * Value must be a positive integer.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#active_deadline_seconds Daemonset#active_deadline_seconds}
     *
     * @stability stable
     */
    readonly activeDeadlineSeconds?: number;
    /**
     * AutomountServiceAccountToken indicates whether a service account token should be automatically mounted.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#automount_service_account_token Daemonset#automount_service_account_token}
     *
     * @stability stable
     */
    readonly automountServiceAccountToken?: boolean;
    /**
     * Set DNS policy for containers within the pod.
     *
     * Valid values are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy. To have DNS options set along with hostNetwork, you have to specify DNS policy explicitly to 'ClusterFirstWithHostNet'. Optional: Defaults to 'ClusterFirst', see [Kubernetes reference](https://kubernetes.io/docs/concepts/services-networking/dns-pod-service/#pod-s-dns-policy).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#dns_policy Daemonset#dns_policy}
     *
     * @stability stable
     */
    readonly dnsPolicy?: string;
    /**
     * Enables generating environment variables for service discovery. Defaults to true.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#enable_service_links Daemonset#enable_service_links}
     *
     * @stability stable
     */
    readonly enableServiceLinks?: boolean;
    /**
     * Use the host's ipc namespace. Optional: Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host_ipc Daemonset#host_ipc}
     *
     * @stability stable
     */
    readonly hostIpc?: boolean;
    /**
     * Host networking requested for this pod.
     *
     * Use the host's network namespace. If this option is set, the ports that will be used must be specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host_network Daemonset#host_network}
     *
     * @stability stable
     */
    readonly hostNetwork?: boolean;
    /**
     * Use the host's pid namespace.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host_pid Daemonset#host_pid}
     *
     * @stability stable
     */
    readonly hostPid?: boolean;
    /**
     * Specifies the hostname of the Pod If not specified, the pod's hostname will be set to a system-defined value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#hostname Daemonset#hostname}
     *
     * @stability stable
     */
    readonly hostname?: string;
    /**
     * NodeName is a request to schedule this pod onto a specific node.
     *
     * If it is non-empty, the scheduler simply schedules this pod onto that node, assuming that it fits resource requirements.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#node_name Daemonset#node_name}
     *
     * @stability stable
     */
    readonly nodeName?: string;
    /**
     * NodeSelector is a selector which must be true for the pod to fit on a node.
     *
     * Selector which must match a node's labels for the pod to be scheduled on that node. More info: http://kubernetes.io/docs/user-guide/node-selection.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#node_selector Daemonset#node_selector}
     *
     * @stability stable
     */
    readonly nodeSelector?: {
        [key: string]: string;
    };
    /**
     * If specified, indicates the pod's priority.
     *
     * "system-node-critical" and "system-cluster-critical" are two special keywords which indicate the highest priorities with the former being the highest priority. Any other name must be defined by creating a PriorityClass object with that name. If not specified, the pod priority will be default or zero if there is no default.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#priority_class_name Daemonset#priority_class_name}
     *
     * @stability stable
     */
    readonly priorityClassName?: string;
    /**
     * Restart policy for all containers within the pod. One of Always, OnFailure, Never. More info: http://kubernetes.io/docs/user-guide/pod-states#restartpolicy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#restart_policy Daemonset#restart_policy}
     *
     * @stability stable
     */
    readonly restartPolicy?: string;
    /**
     * ServiceAccountName is the name of the ServiceAccount to use to run this pod. More info: http://releases.k8s.io/HEAD/docs/design/service_accounts.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#service_account_name Daemonset#service_account_name}
     *
     * @stability stable
     */
    readonly serviceAccountName?: string;
    /**
     * Share a single process namespace between all of the containers in a pod.
     *
     * When this is set containers will be able to view and signal processes from other containers in the same pod, and the first process in each container will not be assigned PID 1. HostPID and ShareProcessNamespace cannot both be set. Optional: Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#share_process_namespace Daemonset#share_process_namespace}
     *
     * @stability stable
     */
    readonly shareProcessNamespace?: boolean;
    /**
     * If specified, the fully qualified Pod hostname will be "...svc.". If not specified, the pod will not have a domainname at all..
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#subdomain Daemonset#subdomain}
     *
     * @stability stable
     */
    readonly subdomain?: string;
    /**
     * Optional duration in seconds the pod needs to terminate gracefully.
     *
     * May be decreased in delete request. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period will be used instead. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#termination_grace_period_seconds Daemonset#termination_grace_period_seconds}
     *
     * @stability stable
     */
    readonly terminationGracePeriodSeconds?: number;
    /**
     * affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#affinity Daemonset#affinity}
     *
     * @stability stable
     */
    readonly affinity?: DaemonsetSpecTemplateSpecAffinity[];
    /**
     * container block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#container Daemonset#container}
     *
     * @stability stable
     */
    readonly container?: DaemonsetSpecTemplateSpecContainer[];
    /**
     * dns_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#dns_config Daemonset#dns_config}
     *
     * @stability stable
     */
    readonly dnsConfig?: DaemonsetSpecTemplateSpecDnsConfig[];
    /**
     * host_aliases block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#host_aliases Daemonset#host_aliases}
     *
     * @stability stable
     */
    readonly hostAliases?: DaemonsetSpecTemplateSpecHostAliases[];
    /**
     * image_pull_secrets block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#image_pull_secrets Daemonset#image_pull_secrets}
     *
     * @stability stable
     */
    readonly imagePullSecrets?: DaemonsetSpecTemplateSpecImagePullSecrets[];
    /**
     * init_container block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#init_container Daemonset#init_container}
     *
     * @stability stable
     */
    readonly initContainer?: DaemonsetSpecTemplateSpecInitContainer[];
    /**
     * readiness_gate block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#readiness_gate Daemonset#readiness_gate}
     *
     * @stability stable
     */
    readonly readinessGate?: DaemonsetSpecTemplateSpecReadinessGate[];
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#security_context Daemonset#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: DaemonsetSpecTemplateSpecSecurityContext[];
    /**
     * toleration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#toleration Daemonset#toleration}
     *
     * @stability stable
     */
    readonly toleration?: DaemonsetSpecTemplateSpecToleration[];
    /**
     * topology_spread_constraint block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#topology_spread_constraint Daemonset#topology_spread_constraint}
     *
     * @stability stable
     */
    readonly topologySpreadConstraint?: DaemonsetSpecTemplateSpecTopologySpreadConstraint[];
    /**
     * volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#volume Daemonset#volume}
     *
     * @stability stable
     */
    readonly volume?: DaemonsetSpecTemplateSpecVolume[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpecTemplate {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#metadata Daemonset#metadata}
     *
     * @stability stable
     */
    readonly metadata: DaemonsetSpecTemplateMetadata[];
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#spec Daemonset#spec}
     *
     * @stability stable
     */
    readonly spec?: DaemonsetSpecTemplateSpec[];
}
/**
 * @stability stable
 */
export interface DaemonsetSpec {
    /**
     * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available.
     *
     * Defaults to 0 (pod will be considered available as soon as it is ready)
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#min_ready_seconds Daemonset#min_ready_seconds}
     *
     * @stability stable
     */
    readonly minReadySeconds?: number;
    /**
     * The number of old ReplicaSets to retain to allow rollback.
     *
     * This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#revision_history_limit Daemonset#revision_history_limit}
     *
     * @stability stable
     */
    readonly revisionHistoryLimit?: number;
    /**
     * selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#selector Daemonset#selector}
     *
     * @stability stable
     */
    readonly selector?: DaemonsetSpecSelector[];
    /**
     * strategy block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#strategy Daemonset#strategy}
     *
     * @stability stable
     */
    readonly strategy?: DaemonsetSpecStrategy[];
    /**
     * template block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#template Daemonset#template}
     *
     * @stability stable
     */
    readonly template: DaemonsetSpecTemplate[];
}
/**
 * @stability stable
 */
export interface DaemonsetTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#create Daemonset#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#delete Daemonset#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html#update Daemonset#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html kubernetes_daemonset}.
 *
 * @stability stable
 */
export declare class Daemonset extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/daemonset.html kubernetes_daemonset} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DaemonsetConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _waitForRollout?;
    /**
     * @stability stable
     */
    get waitForRollout(): boolean;
    /**
     * @stability stable
     */
    set waitForRollout(value: boolean);
    /**
     * @stability stable
     */
    resetWaitForRollout(): void;
    /**
     * @stability stable
     */
    get waitForRolloutInput(): boolean | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): DaemonsetMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: DaemonsetMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): DaemonsetMetadata[];
    private _spec;
    /**
     * @stability stable
     */
    get spec(): DaemonsetSpec[];
    /**
     * @stability stable
     */
    set spec(value: DaemonsetSpec[]);
    /**
     * @stability stable
     */
    get specInput(): DaemonsetSpec[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DaemonsetTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DaemonsetTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DaemonsetTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
